# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-13 14:07
# @Author : 毛鹏
from ...uidrive._base_data import BaseData


class PlaywrightCustomization(BaseData):
    """定制开发"""
